@@ -13,6 +13,7 @@ import (
 	"github.com/pkg/errors"
 	"github.com/superfly/flyctl/agent"
 	"github.com/superfly/flyctl/api"
+	"github.com/superfly/flyctl/client"
 	"github.com/superfly/flyctl/cmdctx"
 	"github.com/superfly/flyctl/flypg"
 	"github.com/superfly/flyctl/helpers"
@@ -250,7 +251,7 @@ func runAttachPostgresCluster(cmdCtx *cmdctx.CmdContext) error {
 
 	MinPostgresHaVersion := "0.0.19"
 
-	ctx := cmdCtx.Command.Context()
+	ctx := client.NewContext(cmdCtx.Command.Context(), cmdCtx.Client)
 
 	postgresAppName := cmdCtx.Config.GetString("postgres-app")
 	appName := cmdCtx.AppName
@@ -307,7 +308,15 @@ func runAttachPostgresCluster(cmdCtx *cmdctx.CmdContext) error {
 		return fmt.Errorf("ssh: can't build tunnel for %s: %s", pgApp.Organization.Slug, err)
 	}
 
-	pgclient := flypg.New(postgresAppName, dialer)
+	instances, err := agentclient.Instances(ctx, pgApp.Organization.Slug, pgApp.Name)
+	if err != nil {
+		return err
+	}
+	if len(instances.Addresses) == 0 {
+		return fmt.Errorf("no instances found for org: %s app: %s", pgApp.Organization.Slug, pgApp.Name)
+	}
+	pgInstanceIp := instances.Addresses[0]
+	pgclient := flypg.NewFromInstance(pgInstanceIp, dialer)
 
 	secrets, err := client.GetAppSecrets(ctx, appName)
 	if err != nil {
