@@ -287,9 +287,9 @@ func (l *Launcher) getPostgresConfig(config *CreateClusterInput) *api.MachineCon
 		},
 	}
 
-	// medatata
+	// Metadata
 	machineConfig.Metadata = map[string]string{
-		"image_version_tracking_enabled": "true",
+		"managed-by-fly-deploy": "true",
 	}
 
 	// Restart policy
