@@ -109,11 +109,23 @@ func runAttach(ctx context.Context) error {
 	}
 	ctx = agent.DialerWithContext(ctx, dialer)
 
+	var leaderIp string
 	switch pgApp.PlatformVersion {
 	case "nomad":
 		if err := hasRequiredVersionOnNomad(pgApp, MinPostgresHaVersion, MinPostgresHaVersion); err != nil {
 			return err
 		}
+		pgInstances, err := agentclient.Instances(ctx, pgApp.Organization.Slug, pgApp.Name)
+		if err != nil {
+			return fmt.Errorf("failed to lookup 6pn ip for %s app: %v", pgAppName, err)
+		}
+		if len(pgInstances.Addresses) == 0 {
+			return fmt.Errorf("no 6pn ips found for %s app", pgAppName)
+		}
+		leaderIp, err = leaderIpFromNomadInstances(ctx, pgInstances.Addresses)
+		if err != nil {
+			return err
+		}
 	case "machines":
 		flapsClient, err := flaps.New(ctx, pgApp)
 		if err != nil {
@@ -127,10 +139,12 @@ func runAttach(ctx context.Context) error {
 		if err := hasRequiredVersionOnMachines(members, MinPostgresHaVersion, MinPostgresHaVersion); err != nil {
 			return err
 		}
+		leader, _ := machinesNodeRoles(ctx, members)
+		leaderIp = leader.PrivateIP
 	default:
 	}
 
-	pgclient := flypg.New(pgAppName, dialer)
+	pgclient := flypg.NewFromInstance(leaderIp, dialer)
 
 	secrets, err := client.GetAppSecrets(ctx, appName)
 	if err != nil {
