@@ -11,7 +11,9 @@ import (
 
 	"golang.org/x/sync/errgroup"
 
+	"github.com/avast/retry-go/v4"
 	"github.com/morikuni/aec"
+	"github.com/samber/lo"
 	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/flaps"
 	"github.com/superfly/flyctl/iostreams"
@@ -291,87 +293,71 @@ func renderLogs(ctx context.Context, alloc *api.AllocationStatus) {
 	}
 }
 
-func MachinesChecks(ctx context.Context, machines []*api.Machine) (err error) {
-	var (
-		io          = iostreams.FromContext(ctx)
-		colorize    = io.ColorScheme()
-		flapsClient = flaps.FromContext(ctx)
-	)
+func MachinesChecks(ctx context.Context, machines []*api.Machine) error {
+	io := iostreams.FromContext(ctx)
+	colorize := io.ColorScheme()
+
+	// m.Checks is empty on launch, we have to look at m.Config.Checks for expected count
+	checksTotal := lo.SumBy(machines, func(m *api.Machine) int { return len(m.Config.Checks) })
+	if checksTotal == 0 {
+		fmt.Fprintln(io.Out, "No health checks found")
+		return nil
+	}
+
+	machineIDs := lo.Map(machines, func(m *api.Machine, _ int) string { return m.ID })
 	ctx, cancel := context.WithTimeout(ctx, 300*time.Second)
 	defer cancel()
+	iteration := 0
 
-	ticker := time.NewTicker(1 * time.Second)
-	defer ticker.Stop()
+	fn := func() error {
+		checked, err := retryGetMachines(ctx, machineIDs...)
+		if err != nil {
+			return retry.Unrecoverable(err)
+		}
 
-	var iterations int
-	var errCount int
+		iteration++
+		if io.IsInteractive() && iteration > 1 {
+			builder := aec.EmptyBuilder
+			str := builder.Up(uint(len(checked))).EraseLine(aec.EraseModes.All).ANSI
+			fmt.Fprint(io.ErrOut, str.String())
+		}
 
-	for {
-		select {
-		case <-ctx.Done():
-			return ctx.Err()
-		case <-ticker.C:
-			var allChecks []*api.MachineCheckStatus
-			var checked []*api.Machine
-
-			err = func() (err error) {
-				for _, machine := range machines {
-					machine, err = flapsClient.Get(ctx, machine.ID)
-					if err != nil {
-						return
-					}
-					checked = append(checked, machine)
-
-				}
-				return
-			}()
-			if err != nil {
-				errCount++
-				if errCount > 6 {
-					return
-				}
+		checksPassed := 0
+		for _, machine := range checked {
+			if machine.Config.Checks == nil {
 				continue
 			}
-
-			iterations++
-
-			if io.IsInteractive() && iterations > 1 {
-				builder := aec.EmptyBuilder
-				str := builder.Up(uint(len(checked))).EraseLine(aec.EraseModes.All).ANSI
-				fmt.Fprint(io.ErrOut, str.String())
-			}
-
-			for _, machine := range checked {
-				if machine.Config.Checks == nil {
-					continue
-				}
-
-				allChecks = append(allChecks, machine.Checks...)
-
-				var pass, _, _ = countChecks(machine.Checks)
-
-				// Waiting for xxxxxxxx to become healthy (started, 3/3)
-				fmt.Fprintf(io.ErrOut, "  Waiting for %s to become healthy (%s, %s)\n",
-					colorize.Bold(machine.ID),
-					colorize.Green(machine.State),
-					colorize.Green(fmt.Sprintf("%d/%d", pass, len(machine.Checks))),
-				)
-			}
-
-			if len(allChecks) == 0 {
-				fmt.Fprintln(io.Out)
-
-				fmt.Fprintln(io.Out, "No health checks found")
-				return
-			}
-			var pass, _, _ = countChecks(allChecks)
-
-			// if all checks are passing, we're done
-			if pass == len(allChecks) {
-				return
-			}
+			pass, _, _ := countChecks(machine.Checks)
+			checksPassed += pass
+			// Waiting for xxxxxxxx to become healthy (started, 3/3)
+			fmt.Fprintf(io.ErrOut, "  Waiting for %s to become healthy (%s, %s)\n",
+				colorize.Bold(machine.ID),
+				colorize.Green(machine.State),
+				colorize.Green(fmt.Sprintf("%d/%d", pass, len(machine.Checks))),
+			)
 		}
+
+		// if all checks are passing, we're done
+		if checksPassed != checksTotal {
+			return fmt.Errorf("Waiting for %d non-passing checks", checksTotal-checksPassed)
+		}
+		return nil
 	}
+
+	return retry.Do(fn, retry.Delay(time.Second), retry.DelayType(retry.FixedDelay), retry.Attempts(0), retry.Context(ctx))
+}
+
+// retryGetMachines calls flaps with exponential backoff 10s max interval and up to 6 times
+func retryGetMachines(ctx context.Context, machineIDs ...string) (result []*api.Machine, err error) {
+	flapsClient := flaps.FromContext(ctx)
+	err = retry.Do(
+		func() (err2 error) {
+			result, err2 = flapsClient.GetMany(ctx, machineIDs)
+			return err2
+		},
+		retry.Attempts(6), retry.MaxDelay(10*time.Second), retry.Context(ctx),
+	)
+	return
 }
 
 func countChecks(checks []*api.MachineCheckStatus) (pass, warn, crit int) {
